// Aseprite Base Library
// Copyright (c) 2001-2013, 2015 David Capello
//
// This file is released under the terms of the MIT license.
// Read LICENSE.txt for more information.

#ifndef BASE_MEM_UTILS_H_INCLUDED
#define BASE_MEM_UTILS_H_INCLUDED
#pragma once

#include <string>

namespace base {

  std::string get_pretty_memory_size(std::size_t memsize);

} // namespace base

#endif
